input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}input[type="number"]{-moz-appearance:textfield}.input-number[theme="default"]{--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.input-number[theme="default"]:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.dark .input-number[theme="default"]{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))}.input-dropdown[theme="default"] .selector{--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-dropdown[theme="default"] .selector:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-dropdown[theme="default"] .dark .selector{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dropdown-menu{--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-dropdown[theme="default"] .dropdown-item{--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity))
}.input-dropdown[theme="default"] .dropdown-item:hover{font-weight:600
}.input-dropdown[theme="default"] .dark .dropdown-item{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))
}.selected.svelte-16244m0 .check.svelte-16244m0{opacity:1
}.input-checkbox[theme="default"].svelte-16244m0 .checkbox-item.svelte-16244m0{--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox[theme="default"].svelte-16244m0 .checkbox-item.svelte-16244m0:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-checkbox[theme="default"].svelte-16244m0 .dark .checkbox-item.svelte-16244m0{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))
}.input-checkbox[theme="default"].svelte-16244m0 .checkbox-item.selected.svelte-16244m0{--tw-bg-opacity:1;background-color:rgb(245 158 11 / var(--tw-bg-opacity));--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity))
}.input-checkbox[theme="default"].svelte-16244m0 .dark .checkbox-item.selected.svelte-16244m0{--tw-bg-opacity:1;background-color:rgb(220 38 38 / var(--tw-bg-opacity))
}.selected.svelte-1nlkb3u .check.svelte-1nlkb3u{opacity:1
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .checkbox-item.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .checkbox-item.svelte-1nlkb3u:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .dark .checkbox-item.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .checkbox.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(243 244 246 / var(--tw-bg-opacity));transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .dark .checkbox.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(156 163 175 / var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .checkbox-item.selected.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(245 158 11 / var(--tw-bg-opacity));--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity))
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .dark .checkbox-item.selected.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(220 38 38 / var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .selected .checkbox.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(217 119 6 / var(--tw-bg-opacity))
}.input-checkbox-group[theme="default"].svelte-1nlkb3u .dark .selected .checkbox.svelte-1nlkb3u{--tw-bg-opacity:1;background-color:rgb(185 28 28 / var(--tw-bg-opacity))
}.range.svelte-3yz621.svelte-3yz621::-webkit-slider-thumb{-webkit-appearance:none;height:1.25rem;width:1.25rem;cursor:pointer;appearance:none;border-radius:0.25rem}.range.svelte-3yz621.svelte-3yz621::-moz-range-thumb{height:1.25rem;width:1.25rem;cursor:pointer;appearance:none;border-radius:0.25rem}.input-slider[theme="default"].svelte-3yz621 .range.svelte-3yz621{height:0.75rem;--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.input-slider[theme="default"].svelte-3yz621 .range.svelte-3yz621:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-3yz621 .dark .range.svelte-3yz621{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))}.input-slider[theme="default"].svelte-3yz621 .range.svelte-3yz621::-webkit-slider-thumb{background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgb(251 191 36 / 0));--tw-gradient-to:#f59e0b;--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-slider[theme="default"].svelte-3yz621 .dark .range.svelte-3yz621::-webkit-slider-thumb{--tw-gradient-from:#ef4444;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgb(239 68 68 / 0));--tw-gradient-to:#dc2626}.input-slider[theme="default"].svelte-3yz621 .range.svelte-3yz621::-moz-range-thumb{background-image:linear-gradient(to bottom, var(--tw-gradient-stops));--tw-gradient-from:#fbbf24;--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgb(251 191 36 / 0));--tw-gradient-to:#f59e0b;--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.input-radio[theme="default"].svelte-1qptfa1 .radio-item.svelte-1qptfa1{--tw-bg-opacity:1;background-color:rgb(255 255 255 / var(--tw-bg-opacity));--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms
}.input-radio[theme="default"].svelte-1qptfa1 .radio-item.svelte-1qptfa1:hover{--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-radio[theme="default"].svelte-1qptfa1 .dark .radio-item.svelte-1qptfa1{--tw-bg-opacity:1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))
}.input-radio[theme="default"].svelte-1qptfa1 .radio-circle.svelte-1qptfa1{box-sizing:border-box;height:1rem;width:1rem;border-radius:9999px
}.input-radio[theme="default"].svelte-1qptfa1 .radio-item.selected.svelte-1qptfa1{--tw-bg-opacity:1;background-color:rgb(245 158 11 / var(--tw-bg-opacity));--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity));--tw-shadow:0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.input-radio[theme="default"].svelte-1qptfa1 .dark .radio-item.selected.svelte-1qptfa1{--tw-bg-opacity:1;background-color:rgb(220 38 38 / var(--tw-bg-opacity))
}